package com.ruoyi.system.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BNet;
import com.ruoyi.system.service.IBNetService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网络Controller
 * 
 * @author ruoyi
 * @date 2023-11-21
 */
@RestController
@RequestMapping("/netEwm/net")
public class BNetController extends BaseController
{
    @Autowired
    private IBNetService bNetService;

    /**
     * 查询网络列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:net:list')")
    @GetMapping("/list")
    public TableDataInfo list(BNet bNet)
    {
        startPage();
        List<BNet> list = bNetService.selectBNetList(bNet);
        return getDataTable(list);
    }

    /**
     * 导出网络列表
     */
    @PreAuthorize("@ss.hasPermi('netEwm:net:export')")
    @Log(title = "网络", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BNet bNet)
    {
        List<BNet> list = bNetService.selectBNetList(bNet);
        ExcelUtil<BNet> util = new ExcelUtil<BNet>(BNet.class);
        util.exportExcel(response, list, "网络数据");
    }

    /**
     * 获取网络详细信息
     */
    @PreAuthorize("@ss.hasPermi('netEwm:net:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bNetService.selectBNetById(id));
    }

    /**
     * 新增网络
     */
    @PreAuthorize("@ss.hasPermi('netEwm:net:add')")
    @Log(title = "网络", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BNet bNet)
    {
        return toAjax(bNetService.insertBNet(bNet));
    }

    /**
     * 修改网络
     */
    @PreAuthorize("@ss.hasPermi('netEwm:net:edit')")
    @Log(title = "网络", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BNet bNet)
    {
        return toAjax(bNetService.updateBNet(bNet));
    }

    /**
     * 删除网络
     */
    @PreAuthorize("@ss.hasPermi('netEwm:net:remove')")
    @Log(title = "网络", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bNetService.deleteBNetByIds(ids));
    }
}
